Index: distools/aucdlpc.m
===================================================================
--- distools/aucdlpc.m	(revision 66)
+++ distools/aucdlpc.m	(revision 79)
@@ -43,5 +43,5 @@
 
 if nargin < 1 | isempty(d)
-    w = mapping(mfilename,C);
+    w = prmapping(mfilename,C);
     w = setname(w,'AUCDLPC');
     return
Index: distools/augpsem.m
===================================================================
--- distools/augpsem.m	(revision 66)
+++ distools/augpsem.m	(revision 79)
@@ -67,5 +67,5 @@
 if nargin < 2 | isempty(alf), alf = inf; end
 if nargin < 1 | isempty(d)
-   W = mapping(mfilename,alf,pzero);
+   W = prmapping(mfilename,alf,pzero);
    W = setname(W,'Augmented PE embedding');
    return
@@ -196,5 +196,5 @@
 %%%%% ---------------------------------------------- %%%%%
 
-W = mapping(mfilename,'trained',{Wp,Wn,dme,pzero,tsig,sig,tol},[],m,sum(sig));
+W = prmapping(mfilename,'trained',{Wp,Wn,dme,pzero,tsig,sig,tol},[],m,sum(sig));
 W = setname(W,'Augmented PE embedding');
 return
Index: distools/checkeucl.m
===================================================================
--- distools/checkeucl.m	(revision 66)
+++ distools/checkeucl.m	(revision 79)
@@ -49,5 +49,5 @@
 	end
 
-	D = dataset(D,1);  % we are not interested in labels here.
+	D = prdataset(D,1);  % we are not interested in labels here.
 	D = setfeatlab(D,ones(m,1));
 	
Index: distools/checksubeucl.m
===================================================================
--- distools/checksubeucl.m	(revision 66)
+++ distools/checksubeucl.m	(revision 79)
@@ -20,5 +20,5 @@
 discheck(d)
 m = size(d,1);
-d = dataset(+d,1);
+d = prdataset(+d,1);
 d = setfeatlab(d,ones(m,1));
 
Index: distools/corrdistm.m
===================================================================
--- distools/corrdistm.m	(revision 66)
+++ distools/corrdistm.m	(revision 79)
@@ -10,5 +10,5 @@
 %
 % OUTPUT
-%   D   NxM dissimilarity matrix or dataset; D in [0,1]
+%   D   NxM dissimilarity matrix or prdataset; D in [0,1]
 %
 % DESCRIPTION
Index: distools/cosdistm.m
===================================================================
--- distools/cosdistm.m	(revision 66)
+++ distools/cosdistm.m	(revision 79)
@@ -10,5 +10,5 @@
 %
 % OUTPUT
-%   D   NxM Dissimilarity matrix or dataset; D in [0,1]
+%   D   NxM Dissimilarity matrix or prdataset; D in [0,1]
 %
 % DESCRIPTION
Index: distools/discc.m
===================================================================
--- distools/discc.m	(revision 66)
+++ distools/discc.m	(revision 79)
@@ -34,12 +34,12 @@
 if nargin < 1 | isempty(d)
 	if isstr(par)	% untrained classifier, par = 'loo' or 'all'
-		W = mapping('discc',par);
+		W = prmapping('discc',par);
 	else			% fixed classifier, par = knn
-		W = mapping('discc','fixed',par);
+		W = prmapping('discc','fixed',par);
 	end
 	return
 end
 
-[nlab,lablist,m,k,c,p,featlist] = dataset(d);
+[nlab,lablist,m,k,c,p,featlist] = prdataset(d);
 [clab,classlist] = renumlab(featlist);
 c = size(classlist,1);
@@ -78,6 +78,6 @@
 			K = K+k;
 		end
-		w = +(dataset(s,2-(t==r))*loglc);
-		W = mapping('discc',w,lablist,k,c,1);
+		w = +(prdataset(s,2-(t==r))*loglc);
+		W = prmapping('discc',w,lablist,k,c,1);
 	elseif strcmp(par,'all')
 		n = m*k;
@@ -92,6 +92,6 @@
 			K = K+k;
 		end
-		w = +(dataset(s,2-(t==r))*loglc);
-		W = mapping('discc',w,lablist,k,c,1);
+		w = +(prdataset(s,2-(t==r))*loglc);
+		W = prmapping('discc',w,lablist,k,c,1);
 	else
 		error(['Unknown option ''' par ''''])
@@ -102,5 +102,5 @@
 	% testing for given mapping
 		
-	if isa(par,'mapping')
+	if isa(par,'prmapping')
 		w = +par;
 		W = d*w(1) + w(2);
Index: distools/disnorm.m
===================================================================
--- distools/disnorm.m	(revision 66)
+++ distools/disnorm.m	(revision 79)
@@ -35,5 +35,5 @@
 
 if nargin == 0 | isempty(D)
-  V = mapping(mfilename,{opt});
+  V = prmapping(mfilename,{opt});
   V = setname(V,'Disnorm');
   return
@@ -41,5 +41,5 @@
 
 if ~isdataset(D)
-	D = dataset(D,1);
+	D = prdataset(D,1);
 	D = setfeatlab(D,getlabels(D));
 end
@@ -60,5 +60,5 @@
 		D = D./m;
 	end	
-    V = mapping(mfilename,'trained',{m},[],size(D,2),size(D,2));
+    V = prmapping(mfilename,'trained',{m},[],size(D,2),size(D,2));
 	return;
 end
Index: distools/dispc.m
===================================================================
--- distools/dispc.m	(revision 66)
+++ distools/dispc.m	(revision 79)
@@ -15,8 +15,8 @@
 
 if nargin < 1 | isempty(a) % empty call (untrained classifier)
-        w = mapping('dispc');
+        w = prmapping('dispc');
 		
 elseif nargin == 1    % training
-	[nlab,lablist,m,k,c,p] = dataset(a);
+	[nlab,lablist,m,k,c,p] = prdataset(a);
 	[nn,nf,fl] = renumlab(lablist,getfeat(a));
 	if c < 2
@@ -37,5 +37,5 @@
 
 		b = {+a(find(nlab==nf(j)),j) +a(find(nlab~=nf(j)),j)};
-		w = [w; mapping('distrc',b,fl(nf(j),:),1,1,1)];
+		w = [w; prmapping('distrc',b,fl(nf(j),:),1,1,1)];
 	end
 
@@ -54,5 +54,5 @@
 	w2(R2(L2)-n2) = (n2+2-(L2-[1:m]'))/(n2+2);
 %	disp([w1;w2])
-	w = invsig(dataset((w1+w2)/2,getlab(a),getfeat(v)));
+	w = invsig(prdataset((w1+w2)/2,getlab(a),getfeat(v)));
 else
 	error('Illegal call')
Index: distools/disrc.m
===================================================================
--- distools/disrc.m	(revision 66)
+++ distools/disrc.m	(revision 79)
@@ -29,8 +29,8 @@
 
 if nargin < 1 | isempty(a) % empty call (untrained classifier)
-        w = mapping('disrc');
+        w = prmapping('disrc');
 		
 elseif nargin == 1    % training
-	[nlab,lablist,m,k,c,p] = dataset(a);
+	[nlab,lablist,m,k,c,p] = prdataset(a);
 	[nn,nf,fl] = renumlab(lablist,getfeat(a));
 	if c < 2
@@ -43,5 +43,5 @@
 	for j = 1:k
 		b = {+a(find(nlab==nf(j)),j) +a(find(nlab~=nf(j)),j)};
-		w = [w; mapping('disrc',b,fl(nf(j),:),1,1,1)];
+		w = [w; prmapping('disrc',b,fl(nf(j),:),1,1,1)];
 	end
 
@@ -60,5 +60,5 @@
 	w2(R2(L2)-n2) = (n2+2-(L2-[1:m]'))/(n2+2);
 %	disp([w1;w2])
-	w = invsig(dataset((w1+w2)/2,getlab(a),getfeat(v)));
+	w = invsig(prdataset((w1+w2)/2,getlab(a),getfeat(v)));
 else
 	error('Illegal call')
Index: distools/dissimt.m
===================================================================
--- distools/dissimt.m	(revision 66)
+++ distools/dissimt.m	(revision 79)
@@ -58,5 +58,5 @@
 end
 if nargin == 0 | isempty(D)
-  W = mapping(mfilename,'fixed',{type,p});
+  W = prmapping(mfilename,'fixed',{type,p});
   W = setname(W,'Fixed proximity transformation');
   return
Index: distools/dmstspm.m
===================================================================
--- distools/dmstspm.m	(revision 66)
+++ distools/dmstspm.m	(revision 79)
@@ -43,5 +43,5 @@
 end
 if nargin < 1 | isempty(D)
-   W = mapping(mfilename,{K,p});
+   W = prmapping(mfilename,{K,p});
    W = setname(W,'dmstspm');
    return
@@ -140,5 +140,5 @@
 
     [Lmst,d] = kdmst(D,K,p);
-    W = mapping(mfilename,'trained',{Lmst,d,K},[],n,n);
+    W = prmapping(mfilename,'trained',{Lmst,d,K},[],n,n);
     W = setname(W,'dmstspm');
   end
Index: distools/dprocrustdm.m
===================================================================
--- distools/dprocrustdm.m	(revision 66)
+++ distools/dprocrustdm.m	(revision 79)
@@ -54,5 +54,5 @@
 %
 % SEE ALSO
-% MDS, PCA, PSEM, KPCA, MAPPINGS, DATASETS
+% MDS, PCAM, PSEM, KPCA, MAPPINGS, DATASETS
 %
 % REFERENCE
Index: distools/drsscc.m
===================================================================
--- distools/drsscc.m	(revision 66)
+++ distools/drsscc.m	(revision 79)
@@ -44,5 +44,5 @@
 end
 if nargin < 1 | isempty(D)
-  W = mapping('DRSSCC',{v,N,M,crule});
+  W = prmapping('DRSSCC',{v,N,M,crule});
   return
 end
Index: distools/expdistm.m
===================================================================
--- distools/expdistm.m	(revision 66)
+++ distools/expdistm.m	(revision 79)
@@ -64,6 +64,6 @@
 end
 
-isda = isa(A,'dataset');
-isdb = isa(B,'dataset');
+isda = isa(A,'prdataset');
+isdb = isa(B,'prdataset');
 a = +A;
 b = +B;
Index: distools/fastmapd.m
===================================================================
--- distools/fastmapd.m	(revision 66)
+++ distools/fastmapd.m	(revision 79)
@@ -40,5 +40,5 @@
 end
 if nargin < 1 | isempty(D)
-   W = mapping(mfilename,K); 
+   W = prmapping(mfilename,K); 
    W = setname(W,'Fastmapd');
    return
@@ -66,5 +66,5 @@
       end
 		end		
-    W = dataset(Y,nlab);
+    W = prdataset(Y,nlab);
     return
   end
@@ -133,5 +133,5 @@
 end
 
-W = mapping(mfilename,'trained',{P,dd,X,KK},[],n,KK);
+W = prmapping(mfilename,'trained',{P,dd,X,KK},[],n,KK);
 W = setname(W,'Fastmapd');
 return
Index: distools/genballd.m
===================================================================
--- distools/genballd.m	(revision 66)
+++ distools/genballd.m	(revision 79)
@@ -45,5 +45,5 @@
 
 labs = genlab(n);
-d = dataset(d,labs);
+d = prdataset(d,labs);
 d = setfeatlab(d,labs);
 d = setprior(d,0);
Index: distools/genddat.m
===================================================================
--- distools/genddat.m	(revision 66)
+++ distools/genddat.m	(revision 79)
@@ -100,5 +100,5 @@
 end
 
-[ja,jb] = gendat(dataset([1:n]',nlab),m);
+[ja,jb] = gendat(prdataset([1:n]',nlab),m);
 ja = +ja; 
 jb = +jb;
Index: distools/genrep.m
===================================================================
--- distools/genrep.m	(revision 66)
+++ distools/genrep.m	(revision 79)
@@ -86,5 +86,5 @@
     L = [R; setdiff(L,R)];
   end
-  DR = dataset(D(L,R),labels(L,:),'featlab',labels(R,:));
+  DR = prdataset(D(L,R),labels(L,:),'featlab',labels(R,:));
 else
   if strcmp(strl,'exclude')
@@ -96,6 +96,6 @@
     ;
   end
-  DR = dataset(D(L,R),labels(L,:),'featlab',labels(R,:));
-  DT = dataset(D(T,R),labels(T,:),'featlab',labels(R,:));
+  DR = prdataset(D(L,R),labels(L,:),'featlab',labels(R,:));
+  DT = prdataset(D(T,R),labels(T,:),'featlab',labels(R,:));
 end
 return
Index: distools/ikfd.m
===================================================================
--- distools/ikfd.m	(revision 66)
+++ distools/ikfd.m	(revision 79)
@@ -43,5 +43,5 @@
 end
 if nargin < 1 | isempty(K),
-  W = mapping(mfilename,{alf,isb0});
+  W = prmapping(mfilename,{alf,isb0});
   W = setname(W,'IKFD');
   return
Index: distools/ikpca.m
===================================================================
--- distools/ikpca.m	(revision 66)
+++ distools/ikpca.m	(revision 79)
@@ -44,5 +44,5 @@
 %
 % SEE ALSO
-% MAPPINGS, DATASETS, PCA, PSEM
+% MAPPINGS, DATASETS, PCAM, PSEM
 %
 % REFERENCE
@@ -71,5 +71,5 @@
 end
 if nargin < 1 | isempty(K),
-  W = mapping(mfilename,alf,prec);
+  W = prmapping(mfilename,alf,prec);
   W = setname(W,'IKPCA');
   return
@@ -117,5 +117,5 @@
   L       = L(J);                  % Eigenvalues
 
-  W = mapping(mfilename,'trained',{QL,pars{2},L,sig,pars{5}},[],m,length(J));
+  W = prmapping(mfilename,'trained',{QL,pars{2},L,sig,pars{5}},[],m,length(J));
   W = setname(W,'IKPCA');
   return
@@ -173,5 +173,5 @@
 
 % Determine the mapping
-W = mapping(mfilename,'trained',{QL,Kme,L,sig,prec},[],m,sum(sig));
+W = prmapping(mfilename,'trained',{QL,Kme,L,sig,prec},[],m,sum(sig));
 W = setname(W,'IKPCA');
 return
Index: distools/ispe_em.m
===================================================================
--- distools/ispe_em.m	(revision 66)
+++ distools/ispe_em.m	(revision 79)
@@ -22,5 +22,5 @@
 	prtrace(mfilename);
 	
-	if isa(w,'mapping') & strcmp(w.mapping_file,'pe_em')
+	if isa(w,'prmapping') & strcmp(w.mapping_file,'pe_em')
 		n = 1;
 	else
Index: distools/ispsem.m
===================================================================
--- distools/ispsem.m	(revision 66)
+++ distools/ispsem.m	(revision 79)
@@ -22,5 +22,5 @@
 	prtrace(mfilename);
 	
-	if isa(w,'mapping') & strcmp(w.mapping_file,'psem')
+	if isa(w,'prmapping') & strcmp(w.mapping_file,'psem')
 		n = 1;
 	else
Index: distools/jacsimdistm.m
===================================================================
--- distools/jacsimdistm.m	(revision 66)
+++ distools/jacsimdistm.m	(revision 79)
@@ -10,5 +10,5 @@
 %
 % OUTPUT
-%   D   NxM Dissimilarity matrix or dataset; D in [0,1]
+%   D   NxM Dissimilarity matrix or prdataset; D in [0,1]
 %
 % DESCRIPTION
Index: distools/kcenterm.m
===================================================================
--- distools/kcenterm.m	(revision 66)
+++ distools/kcenterm.m	(revision 79)
@@ -39,5 +39,5 @@
 
 if nargin < 1 | isempty(K)
-   V = mapping(mfilename);
+   V = prmapping(mfilename);
    V = setname(V,'kcenterm');
    return
@@ -101,5 +101,5 @@
 end
 
-V = mapping(mfilename,'trained',{v,Kwm},[],m,m);
+V = prmapping(mfilename,'trained',{v,Kwm},[],m,m);
 V = setname(V,'kcenterm');
 return
Index: distools/kem.m
===================================================================
--- distools/kem.m	(revision 66)
+++ distools/kem.m	(revision 79)
@@ -47,5 +47,5 @@
 %
 % SEE ALSO
-% MAPPINGS, DATASETS, PE_EM, AUGPSEM, PCA, PE_PCA, PE_SPEC, GETSIG, SETSIG
+% MAPPINGS, DATASETS, PE_EM, AUGPSEM, PCAM, PE_PCA, PE_SPEC, GETSIG, SETSIG
 %
 % LITERATURE
@@ -73,5 +73,5 @@
 
 if nargin < 1 | isempty(d),
-  W = mapping(mfilename,{alf,pzero,prec});
+  W = prmapping(mfilename,{alf,pzero,prec});
   W = setname(W,'PE embedding');
   return
@@ -146,5 +146,5 @@
   data.eval = L(J);          % Eigenvalues
  
-  W = mapping(mfilename,'trained',data,[],m,length(J));
+  W = prmapping(mfilename,'trained',data,[],m,length(J));
   W = setname(W,'PE embedding');
   return
@@ -204,8 +204,8 @@
 % Determine the mapping depending on pzero
 if pzero == 0,
-  W = mapping(mfilename,'trained',data,[],m,sum(sig));
+  W = prmapping(mfilename,'trained',data,[],m,sum(sig));
 else
   data.mdis = +d(:,pzero)';
-  W = mapping(mfilename,'trained',data,[],m,sum(sig));
+  W = prmapping(mfilename,'trained',data,[],m,sum(sig));
 end
 W = setname(W,'PE embedding');
Index: distools/kfd.m
===================================================================
--- distools/kfd.m	(revision 66)
+++ distools/kfd.m	(revision 79)
@@ -43,5 +43,5 @@
 end
 if nargin < 1 | isempty(K),
-  W = mapping(mfilename,{alf,isb0});
+  W = prmapping(mfilename,{alf,isb0});
   W = setname(W,'KFD');
   return
Index: distools/knndc.m
===================================================================
--- distools/knndc.m	(revision 66)
+++ distools/knndc.m	(revision 79)
@@ -59,5 +59,5 @@
 % empty call, to handle d*knnd, or d*knnd([],par)			
 if nargin < 1 | isempty(d)
-	W = mapping(mfilename,'untrained',knn,par);
+	W = prmapping(mfilename,'untrained',knn,par);
 	W = setname(W,'KNND');
 	return
@@ -70,5 +70,5 @@
 p        = getprior(d);
 
-%[nlab,lablist,m,k,c,p,featlist] = dataset(d);
+%[nlab,lablist,m,k,c,p,featlist] = prdataset(d);
 [clab,classlist] = renumlab(featlist);
 [cl,nc] = renumlab(classlist,lablist);
@@ -131,5 +131,5 @@
 	end
 	
-	W = mapping(mfilename,'trained',{knn,JJ},lablist,k,c);
+	W = prmapping(mfilename,'trained',{knn,JJ},lablist,k,c);
 	W = setname(W,'KNNDC');
 	
Index: distools/kpca.m
===================================================================
--- distools/kpca.m	(revision 66)
+++ distools/kpca.m	(revision 79)
@@ -31,5 +31,5 @@
 %
 % SEE ALSO
-% MAPPINGS, DATASETS, PCA, PSEM
+% MAPPINGS, DATASETS, PCAM, PSEM
 %
 % REFERENCE
@@ -48,5 +48,5 @@
 end
 if nargin < 1 | isempty(K),
-  W = mapping(mfilename,alf);
+  W = prmapping(mfilename,alf);
   W = setname(W,'Kernel PCA');
   return
@@ -100,5 +100,5 @@
   L = L(J);                 % Eigenvalues
 
-  W = mapping(mfilename,'trained',{Q,pars{2},L},[],m,length(J));
+  W = prmapping(mfilename,'trained',{Q,pars{2},L},[],m,length(J));
   W = setname(W,'KPCA');
   return
@@ -154,5 +154,5 @@
 
 % Determine the mapping
-W = mapping(mfilename,'trained',{Q,Kme,L},[],m,length(J));
+W = prmapping(mfilename,'trained',{Q,Kme,L},[],m,length(J));
 W = setname(W,'KPCA');
 return
Index: distools/ksvc.m
===================================================================
--- distools/ksvc.m	(revision 66)
+++ distools/ksvc.m	(revision 79)
@@ -95,5 +95,5 @@
 end
 if nargin < 1 | isempty(K),
-  W = mapping(mfilename,{C,kc,r});
+  W = prmapping(mfilename,{C,kc,r});
   W = setname(W,'Kernel Support Vector Classifier (KSVC)');
   return;
@@ -115,5 +115,5 @@
 
 % TRAIN THE CLASSIFIER
-if ~isa(C,'mapping')
+if ~isa(C,'prmapping')
   islabtype(K,'crisp');
   isvaldset(K,1,2);      % Expect at least 1 object per class and 2 classes
@@ -167,5 +167,5 @@
 
     % Store the results
-    W = mapping(mfilename,'trained',{me,J,T,v,reg},getlablist(K),k,2);
+    W = prmapping(mfilename,'trained',{me,J,T,v,reg},getlablist(K),k,2);
     % W = cnormc(W,K);
     W = setname(W,'Kernel Support Vector Classifier (KSVC)');
Index: distools/ksvc_nu.m
===================================================================
--- distools/ksvc_nu.m	(revision 66)
+++ distools/ksvc_nu.m	(revision 79)
@@ -113,5 +113,5 @@
 end
 if nargin < 1 | isempty(K),
-  W = mapping(mfilename,{nu,kc,r});
+  W = prmapping(mfilename,{nu,kc,r});
   W = setname(W,'Kernel Support Vector Classifier (KSVC-NU)');
   return;
@@ -134,5 +134,5 @@
 
 % TRAIN THE CLASSIFIER
-if ~isa(nu,'mapping')
+if ~isa(nu,'prmapping')
   islabtype(K,'crisp');
   isvaldset(K,1,2);      % Expect at least 1 object per class and 2 classes
@@ -187,5 +187,5 @@
 
     % Store the results
-    W = mapping(mfilename,'trained',{me,J,T,v},getlablist(K),k,2);
+    W = prmapping(mfilename,'trained',{me,J,T,v},getlablist(K),k,2);
     %W = cnormc(W,a);
     W = setname(W,'Kernel Support Vector Classifier (KSVC-NU)');
Index: distools/mclassdc.m
===================================================================
--- distools/mclassdc.m	(revision 66)
+++ distools/mclassdc.m	(revision 79)
@@ -50,5 +50,5 @@
 end
 if nargin < 1 | isempty(D)
-	w = mapping(mfilename,{classf,mode});
+	w = prmapping(mfilename,{classf,mode});
 	return
 end
@@ -65,5 +65,5 @@
 varout = {};
 if c == 2
-	varargout = map(D,classf);
+	varargout = prmap(D,classf);
 	return
 end
@@ -82,11 +82,11 @@
 			  Dtargets = gettargets(D);
 			  targets  = [Dtargets(:,i) 1-Dtargets(:,i)]; 
-			  DD			 = dataset(+D,mlab,targets,'lablist',[1 2]');
+			  DD			 = prdataset(+D,mlab,targets,'lablist',[1 2]');
 		  end
 			if nargout(classf.mapping_file) > 1
-		 	 	[v,varo] = map(DD,classf);
+		 	 	[v,varo] = prmap(DD,classf);
 				varout   = [varout {varo}];
 			else
-				v = map(DD,classf);
+				v = prmap(DD,classf);
 			end
 			w = [w,setlabels(v(:,1),lablist(i,:))];
@@ -114,8 +114,8 @@
 		  I1 = setdiff([1:c],z);
 			if nargout(classf.mapping_file) > 1
-		 	 	[v,varo] = map(DD,classf);
+		 	 	[v,varo] = prmap(DD,classf);
 				varout   = [varout {varo}];
 			else
-				v = map(DD,classf);
+				v = prmap(DD,classf);
 			end
 			w = [w,setlabels(v(:,1),lab)];
Index: distools/parzenddc.m
===================================================================
--- distools/parzenddc.m	(revision 66)
+++ distools/parzenddc.m	(revision 79)
@@ -29,5 +29,5 @@
   % No input arguments: return an untrained mapping.
   if nargin == 0 | isempty(d)
-    W = mapping(mfilename,h); 
+    W = prmapping(mfilename,h); 
     W = setname(W,'Parzen DisRep Classifier');
     return; 
@@ -146,5 +146,5 @@
   par.weights = ones(m,1);
     
-  W = mapping('parzend_map','trained',par,getlablist(d),k,c);
+  W = prmapping('parzend_map','trained',par,getlablist(d),k,c);
   W = setname(W,'Parzen DisRep Classifier');
   W = setcost(W,d);
Index: distools/pe_affine.m
===================================================================
--- distools/pe_affine.m	(revision 66)
+++ distools/pe_affine.m	(revision 79)
@@ -18,5 +18,5 @@
 	par.map = arg1;
 	par.sig = arg2;
-	argout = mapping(mfilename,'trained',par,getlabels(arg1),n1,n2);
+	argout = prmapping(mfilename,'trained',par,getlabels(arg1),n1,n2);
 else
 	isdataset(arg1);
Index: distools/pe_em.m
===================================================================
--- distools/pe_em.m	(revision 66)
+++ distools/pe_em.m	(revision 79)
@@ -43,5 +43,5 @@
 %
 % SEE ALSO
-% MAPPINGS, DATASETS, AUGPSEM, PCA, GETSIG, SETSIG
+% MAPPINGS, DATASETS, AUGPSEM, PCAM, GETSIG, SETSIG
 %
 % LITERATURE
@@ -70,5 +70,5 @@
 
 if nargin < 1 | isempty(d),
-  W = mapping(mfilename,{alf,pzero,prec});
+  W = prmapping(mfilename,{alf,pzero,prec});
   W = setname(W,'PE embedding');
   return
@@ -143,5 +143,5 @@
   data.eval = L(J);          % Eigenvalues
  
-  W = mapping(mfilename,'trained',data,[],m,length(J));
+  W = prmapping(mfilename,'trained',data,[],m,length(J));
   W = setname(W,'PE embedding');
   return
@@ -200,8 +200,8 @@
 % Determine the mapping depending on pzero
 if pzero == 0,
-  W = mapping(mfilename,'trained',data,[],m,sum(sig));
+  W = prmapping(mfilename,'trained',data,[],m,sum(sig));
 else
   data.mdis = +d(:,pzero)';
-  W = mapping(mfilename,'trained',data,[],m,sum(sig));
+  W = prmapping(mfilename,'trained',data,[],m,sum(sig));
 end
 W = setname(W,'PE embedding');
Index: distools/pe_kernelm.m
===================================================================
--- distools/pe_kernelm.m	(revision 66)
+++ distools/pe_kernelm.m	(revision 79)
@@ -53,12 +53,12 @@
 	if (nargin < 1) | (isempty(a) & nargin == 1)  
 		% Definition: pe kernel mapping.
-		w = mapping(mfilename,{b});
+		w = prmapping(mfilename,{b});
 		w = setname(w,mapname);
   elseif isempty(a)
-    w = mapping(mfilename,'trained',b,getlab(b),size(b,2),size(b,1));
+    w = prmapping(mfilename,'trained',b,getlab(b),size(b,2),size(b,1));
 		w = setname(w,mapname);
   elseif isdataset(a) & ~isempty(a)
     if isempty(b)   % store a as rep set, 'training'
-      w = mapping(mfilename,'trained',a,getlab(a),size(a,2),size(a,1));
+      w = prmapping(mfilename,'trained',a,getlab(a),size(a,2),size(a,1));
 		  w = setname(w,mapname);
     elseif isdataset(b); % compute kernel between a and b
@@ -66,5 +66,5 @@
     elseif ismapping(b)
       if isuntrained(b) % nothing stored yet, do it now, a is rep set
-        w = mapping(mfilename,'trained',a,getlab(a),size(a,2),size(a,1));
+        w = prmapping(mfilename,'trained',a,getlab(a),size(a,2),size(a,1));
 		    w = setname(w,mapname);
       else % we have already a rep set: compute kernel matrix
@@ -77,5 +77,5 @@
     
   else  % may be double ???
-    a = dataset(a);
+    a = prdataset(a);
     w = feval(mfilename,a,b);
     
Index: distools/pe_knnc.m
===================================================================
--- distools/pe_knnc.m	(revision 66)
+++ distools/pe_knnc.m	(revision 79)
@@ -31,5 +31,5 @@
 
 	if nargin == 0 | isempty(a)
-		w = mapping(mfilename,'untrained',{k});
+		w = prmapping(mfilename,'untrained',{k});
 		w = setname(w,'PE K-NN Classifier');
 		
@@ -45,5 +45,5 @@
         e = testkd(pe_distm(a),k,'loo');
 			end
-			w = mapping(mfilename,'trained',{a,k},getlablist(a),size(a,2),getsize(a,3));
+			w = prmapping(mfilename,'trained',{a,k},getlablist(a),size(a,2),getsize(a,3));
 		end
 		
Index: distools/pe_libsvc.m
===================================================================
--- distools/pe_libsvc.m	(revision 66)
+++ distools/pe_libsvc.m	(revision 79)
@@ -42,5 +42,5 @@
 
 	if nargin == 0 | isempty(a)
-		w = mapping(mfilename,'untrained',{c});
+		w = prmapping(mfilename,'untrained',{c});
 		w = setname(w,'PE LIBSVC');
 		
@@ -53,5 +53,5 @@
 			ktrain = pe_kernelm(a,a)
 			v = libsvc(ktrain,0);
-			w = mapping(mfilename,'trained',{v,a},getlablist(a),size(a,2),getsize(a,3));
+			w = prmapping(mfilename,'trained',{v,a},getlablist(a),size(a,2),getsize(a,3));
 		end
 		
Index: distools/pe_nmc.m
===================================================================
--- distools/pe_nmc.m	(revision 66)
+++ distools/pe_nmc.m	(revision 79)
@@ -24,5 +24,5 @@
 
   if nargin == 0 | isempty(a)
-    w = mapping(mfilename,'untrained');
+    w = prmapping(mfilename,'untrained');
     w = setname(w,'PE Nearest Mean');
     
Index: distools/pe_parzenc.m
===================================================================
--- distools/pe_parzenc.m	(revision 66)
+++ distools/pe_parzenc.m	(revision 79)
@@ -31,5 +31,5 @@
 
   if nargin == 0 | isempty(a)
-    w = mapping(mfilename,'untrained',{h});
+    w = prmapping(mfilename,'untrained',{h});
     w = setname(w,'PE Parzen Classifier');
     
@@ -46,5 +46,5 @@
         e = testpd(sqrt(pe_distm(a)),h,'loo');
       end
-      w = mapping(mfilename,'trained',{a,h},getlablist(a),size(a,2),getsize(a,3));
+      w = prmapping(mfilename,'trained',{a,h},getlablist(a),size(a,2),getsize(a,3));
     end
     
Index: distools/private/auclpm.m
===================================================================
--- distools/private/auclpm.m	(revision 66)
+++ distools/private/auclpm.m	(revision 79)
@@ -55,5 +55,5 @@
 		error('Please check your input parameters: C should be a double.');
 	end
-	w = mapping(mfilename,{C,rtype,par,unitnorm,usematlab});
+	w = prmapping(mfilename,{C,rtype,par,unitnorm,usematlab});
 	w = setname(w,defauclpmname(C,rtype,par,unitnorm));
 	return
@@ -204,5 +204,5 @@
 	W.rel = rel;
 	W.C = C;
-	w = mapping(mfilename,'trained',W,tlab,dim,1);
+	w = prmapping(mfilename,'trained',W,tlab,dim,1);
 	w = setname(w,defauclpmname(C,rtype,par,unitnorm));
 	
Index: distools/protselfd.m
===================================================================
--- distools/protselfd.m	(revision 66)
+++ distools/protselfd.m	(revision 79)
@@ -67,5 +67,5 @@
 
   if nargin < 1 || isempty(D)  % allow for D*protselfd([],pars)
-    R = mapping(mfilename,'untrained',{ksel,type});
+    R = prmapping(mfilename,'untrained',{ksel,type});
     R = setname(R,'Forward Prototype Sel');
     return
Index: distools/proxxm.m
===================================================================
--- distools/proxxm.m	(revision 66)
+++ distools/proxxm.m	(revision 79)
@@ -80,5 +80,5 @@
 % No data, return an UNTRAINED mapping
 if (nargin < 1) | (isempty(A))
-  W = mapping(mfilename,{type,s,weights});
+  W = prmapping(mfilename,{type,s,weights});
   W = setname(W,'Proximity mapping');
   return;
@@ -104,7 +104,7 @@
   [m,k] = size(A);
   if isdataset(A)
-    W = mapping(mfilename,'trained',{A,type,s,weights},getlab(A),getfeatsize(A),getobjsize(A));
+    W = prmapping(mfilename,'trained',{A,type,s,weights},getlab(A),getfeatsize(A),getobjsize(A));
   else
-    W = mapping(mfilename,'trained',{A,type,s,weights},[],k,m);
+    W = prmapping(mfilename,'trained',{A,type,s,weights},[],k,m);
   end
   W = setname(W,'Proximity mapping');
Index: distools/prtbunke.m
===================================================================
--- distools/prtbunke.m	(revision 66)
+++ distools/prtbunke.m	(revision 79)
@@ -34,5 +34,5 @@
       end
       if ~isempty(lab),
-        D = dataset(D,lab,'featlab',lab);
+        D = prdataset(D,lab,'featlab',lab);
         C = classsizes(D);
         % Should it be class frequencies or equal priors?
Index: distools/psem.m
===================================================================
--- distools/psem.m	(revision 66)
+++ distools/psem.m	(revision 79)
@@ -79,5 +79,5 @@
 end
 if nargin < 1 | isempty(d),
-  W = mapping(mfilename,{alf,pzero,prec});
+  W = prmapping(mfilename,{alf,pzero,prec});
   W = setname(W,'PE embedding');
   return
@@ -133,5 +133,5 @@
   L = L(J);          % Eigenvalues
 
-  W = mapping(mfilename,'trained',{Q, pars{2},pars{3},L,pars{5},pars{6}},[],m,length(J));
+  W = prmapping(mfilename,'trained',{Q, pars{2},pars{3},L,pars{5},pars{6}},[],m,length(J));
   W = setname(W,'PE embedding');
   return
@@ -186,7 +186,7 @@
 % Determine the mapping depending on pzero
 if pzero == 0,
-  W = mapping(mfilename,'trained',{Q,mean(+d,2)',pzero,L,sig,prec},[],m,sum(sig));
+  W = prmapping(mfilename,'trained',{Q,mean(+d,2)',pzero,L,sig,prec},[],m,sum(sig));
 else
-  W = mapping(mfilename,'trained',{Q,+d(:,pzero)',pzero,L,sig,prec},[],m,sum(sig));
+  W = prmapping(mfilename,'trained',{Q,+d(:,pzero)',pzero,L,sig,prec},[],m,sum(sig));
 end
 W = setname(W,'PE embedding');
Index: distools/pspca.m
===================================================================
--- distools/pspca.m	(revision 66)
+++ distools/pspca.m	(revision 79)
@@ -49,5 +49,5 @@
 %
 % SEE ALSO
-% MAPPINGS, DATASETS, PCA, KPSEM, PSEM
+% MAPPINGS, DATASETS, PCAM, KPSEM, PSEM
 %
 % LITERATURE
@@ -69,5 +69,5 @@
 if nargin < 2 | isempty(sig), sig = [size(a,1) 0]; end
 if nargin < 1 | isempty(a),
-  W = mapping(mfilename,sig,alf,prec);
+  W = prmapping(mfilename,sig,alf,prec);
   W = setname(W,'Pseudo-Euclidean PCA');
   return
@@ -153,5 +153,5 @@
 
 % Determine the mapping
-W = mapping(mfilename,'trained',{v,Q,outsig,sig},[],k,sum(outsig));
+W = prmapping(mfilename,'trained',{v,Q,outsig,sig},[],k,sum(outsig));
 W = setname(W,'Pseudo-Euclidean PCA');
 return
Index: distools/setsig.m
===================================================================
--- distools/setsig.m	(revision 66)
+++ distools/setsig.m	(revision 79)
@@ -40,5 +40,5 @@
   if nargin < 2, sig = []; end
   if nargin < 1 | isempty(a)
-    b = mapping(mfilename,'fixed',{sig});
+    b = prmapping(mfilename,'fixed',{sig});
     b = setname(b,'Set signature');
     return
@@ -58,5 +58,5 @@
 		b = setdata(a,data);
 	else
-		a = dataset(a);
+		a = prdataset(a);
         	b = setuser(a,sig,'pe_signature');
 	end
Index: distools/simdistm.m
===================================================================
--- distools/simdistm.m	(revision 66)
+++ distools/simdistm.m	(revision 79)
@@ -8,5 +8,5 @@
 %
 % OUTPUT
-%   D   NxM dissimilarity matrix or dataset; D in [0,1]
+%   D   NxM dissimilarity matrix or prdataset; D in [0,1]
 %
 % DESCRIPTION
Index: distools/sphem.m
===================================================================
--- distools/sphem.m	(revision 66)
+++ distools/sphem.m	(revision 79)
@@ -62,5 +62,5 @@
 if nargin < 2 | isempty(R), R = 1; end
 if nargin < 1 | isempty(d),
-  W = mapping(mfilename,{R,alf,prec});
+  W = prmapping(mfilename,{R,alf,prec});
   W = setname(W,'Spherical embedding');
   return
@@ -82,5 +82,5 @@
     W = R^2*(cos(+d/R)) * Q * diag(sqrt(abs(L))./L);
     if isdataset(d),
-      W = dataset(W,getlab(d),'prior',getprior(d));
+      W = prdataset(W,getlab(d),'prior',getprior(d));
 
       % Store signature in the USER field
@@ -109,5 +109,5 @@
   L = L(J);          % Eigenvalues
 
-  W = mapping(mfilename,'trained',{R,Q,L,pars{4},pars{5}},[],m,length(J));
+  W = prmapping(mfilename,'trained',{R,Q,L,pars{4},pars{5}},[],m,length(J));
   W = setname(W,'Spherical embedding');
   return
@@ -150,5 +150,5 @@
 Q = Q(:,J);                   % Eigenvectors
 
-W = mapping(mfilename,'trained',{R,Q,L,sig,prec},[],m,sum(sig));
+W = prmapping(mfilename,'trained',{R,Q,L,sig,prec},[],m,sum(sig));
 W = setname(W,'Spherical  embedding');
 return
Index: distools/tqdc.m
===================================================================
--- distools/tqdc.m	(revision 66)
+++ distools/tqdc.m	(revision 79)
@@ -77,5 +77,5 @@
 % No input arguments: return an UNTRAINED mapping
 if (nargin < 1) | (isempty(a))
-  w = mapping(mfilename,{alf,r,s,dim});
+  w = prmapping(mfilename,{alf,r,s,dim});
   w = setname(w,'Trade-off Bayes-Normal-2');
   return
@@ -144,5 +144,5 @@
 end
 
-w = mapping('normal_map','trained',pars,getlab(U),k,c);
+w = prmapping('normal_map','trained',pars,getlab(U),k,c);
 w = setname(w,'Trade-off Bayes-Normal-2');
 w = setcost(w,a);

Index: distools/dlpc.m
===================================================================
--- distools/dlpc.m	(revision 66)
+++ distools/dlpc.m	(revision 79)
@@ -25,5 +25,5 @@
 %   W1  LP-Classifier in the complete dissimilarity space
 %   W2  LP-Classifier in a reduced dissimilarity space
 %   W3  Object selection mapping; the indices of support objects are in +W3.
 %
 % DEFAULTS
@@ -125,5 +125,5 @@
 if nargin < 2 | isempty(is_w0), is_w0 = 1; end
 if nargin < 1 | isempty(d)
-  W1 = mapping(mfilename,{is_w0,type,par,usematlab});
+  W1 = prmapping(mfilename,{is_w0,type,par,usematlab});
   W1 = setname(W1,'DLPC');
   W2 = [];
@@ -176,5 +176,5 @@
 % If more than 2 classes, do one against all others.
 if C > 2,
-% W1 = mclassc(d,mapping(mfilename,{is_w0,type,par,usematlab}));
+% W1 = mclassc(d,prmapping(mfilename,{is_w0,type,par,usematlab}));
 
   W1 = [];
@@ -25,5 +25,5 @@
 %   W1  LP-Classifier in the complete dissimilarity space
 %   W2  LP-Classifier in a reduced dissimilarity space
-%   W3  Object selection mapping; the indices of support objects are in +W3.
+%   W3  Object selection prmapping; the indices of support objects are in +W3.
 %
 % DEFAULTS
Index: distools/pe_distm.m
===================================================================
--- distools/pe_distm.m	(revision 66)
+++ distools/pe_distm.m	(revision 79)
@@ -32,5 +32,5 @@
 %
 % SEE ALSO
 % DATASET, SETSIG, DISTM
 
 % Copyright: Elzbieta Pekalska, ela.pekalska@googlemail.com
@@ -47,5 +47,5 @@
   sig = getsig(A);
 
-  if ~isdataset(B), B = dataset(B,1); end
+  if ~isdataset(B), B = prdataset(B,1); end
 
   a    = +A;
@@ -32,5 +32,5 @@
 %
 % SEE ALSO
-% DATASET, SETSIG, DISTM
+% PRDATASET, SETSIG, DISTM
 
 % Copyright: Elzbieta Pekalska, ela.pekalska@googlemail.com